Ч. Алтангэрэл, Ж. Пүрэв, Кирилл Монгол бичвэрийн дуудлагын
хөрвүүлэг, Монголын Мэдээллийн Технологи Хурлын эмхэтгэл,
2018, 19-22

# Кирилл Монгол бичвэрийн дуудлагын хөрвүүлэг Туршилт үнэлгээ 

Чагнаагийн Алтангэрэл Монгол улсын их сургууль Мэдээлэл компьютерийн ухааны тэнхим Улаанбаатар хот, Монгол улс 

Жаймайн Пүрэв Монгол улсын их сургууль Мэдээлэл компьютерийн ухааны тэнхим Улаанбаатар хот, Монгол улс 

Абстракт—Яриа боловсруулалтын үндсэн суурь нөөцийн нэг бол бичвэрийг дуудлагад хөрвүүлэх (БДХ) хэрэгсэл юм. Энэ ажлаар кирилл Монгол бичвэрт зориулсан БДХ загварын авиан олонлогийг өргөтгөж түүнийг яриа танилт болон яриа үүсгэх даалгаварт туршив. Туршилтын үр дүнд өмнөх хувилбараасаа илүү сайжирсан үр дүн үзүүлсэн. Яриа танилтын хувьд үгийн алдааны хэмжээ нь дунджаар 10 хувиар сайжирсан. Яриа үүсгэх даалгаврын хувьд мөн харьцангуй илүү бодит үр дүн өгсөн. БДХ загвараас гадна энэ ажилд шинээр үүсгэж буй Монгол хэлний ярианы сангийн нэг хэсгийг туршилтанд ашигласан. 

Түлхүүр үгс—Бичлэгийг дуудлагад хөрвүүлэх; кирилл Монгол; яриа танилт 

# I. INTRODUCTION 

Монгол хэл нь Алтайн хэлний бүлэгт багтдаг, олон янзын салаа аялгатай, олон газар тархсан яригч бүхий залгамал хэл юм. Энэхүү аялга болон яригчийн тархалтаас олон янз байдлаас гадна Монголчууд хуучин Монгол (ТМ) бичигээс эхлээд олон төрлийн бичиг үсгийг хэрэглэж иржээ. Одоо Монгол улсад кирилл Монгол (СМ) үсгийг албан ёсны бичиг болгон хэрэглэж байна. Энэхүү кирилл үсгийг 1940-өөд онд Орос үсгээс буулган авсан. ТМ үсгийг Өвөр Монголын Өөртөө Засах оронд хэрэглэж, энэ бичигт суурилсан хэл боловсруулалтын судалгааны ажлуудыг идэвхитэй хийж байна. Жишээлбэл уламжлалт Гауссын Холимог Загвараас илүү үр дүн үзүүлсэн гүний мэдрэс сүлжээг ашигласан Монгол хэлний яриа танилтын загварыг хөгжүүлжээ [7]. 

СМ бичгээр хэл боловсруулалтын чиглэлийн судалгаа харьцангуй цөөхөн хийгдсэн байна. Түүний дотроос яриа боловсруулалтын чиглэлээр хийгдэх ажлууд олон байна. Хамгийн сүүлийн үест тусгайрласан үгийн яриа танилтын судалгааг 6000 үгийн хүрээнд [3] , том үгийн сант яриа танилт [12] болон яриа үүсгүүрийн [1] судалгаанууд хийгдсэн байдаг. Цаашид Монгол гэдгээр кирилл Монгол гэдгийг ойлгоно. 

Яриа боловсруулалтын чиглЭлийн судалгааны бичвэртэй холбогдох хэсэгт бичвэрийг дуудлагад хөрвүүлэх (БдХ) хэсэг гол цөм нь болж байдаг. Энэ өгүүлэлд Монгол хэлний БдХ загварыг авч үзнэ. Монгол хэлний БДХ талаар яриа үүсгүүр [2] болон БДХ харьцуулалт [13] зэргийг эс тооцвол өмнө нь тусгайлан судалж илтгэж байгаагүй. Монгол хэлний БДХ загвар, авиан олонлогийг дахин шинэчилж яриа танилт, яриа үүсгүүр болон чиглүүлэгтэй сургалтын 3 өөр хүрээнд туршилтаар үнэллээ 

Энэхүү өгүүлэл дараах бүтэцтэй. Дараагийн бүлэгт, Монгол хэлний авиазүй болон авиан олонлогийг танилцуулна. Удаах бүлэгт ярианы корпус, түүний туршилтад хэрэглэсэн дэд хэсгийн талаар танилцуулна. Туршилт ба үр дүнг 4 дүгээр бүлэгт танилцуулна. Төгсгөлийн бүлэг нь өгүүллийг тоймлон зарим ирээдүйн ажлуудыг тодорхойлсон. 


TABLE I. МОНГОЛ ХЭЛНИЙ ЭГШИГЙ БОЛОН ХАРГАЛЗАХ ДУУДЛАГА 




<table><tr><td colspan="3">Дуудлагын</td></tr><tr><td>Авиа</td><td>тэмдэглэгээ IPA</td><td>Жишээ/Дуудлага</td></tr><tr><td>а</td><td>а</td><td>авдар / al v d a0 r</td></tr><tr><td>е</td><td>э</td><td>эвэр /el v e0 r</td></tr><tr><td>і</td><td>И</td><td>ихэр / i1 x e0 r</td></tr><tr><td>о</td><td>о</td><td>овор/ ol v o0 r</td></tr><tr><td>u</td><td>y</td><td>yn/ul1</td></tr><tr><td>@</td><td>θ</td><td>Θp / @1 r</td></tr><tr><td>л</td><td>Y</td><td>Yp / ^1 r</td></tr><tr><td>у</td><td>ЬI</td><td>тавын/ t al v y n</td></tr><tr><td>ay</td><td>ай</td><td>аймаг / ayl m a0 g</td></tr><tr><td>оу</td><td>ой</td><td>ойлголт / oy1 1 G o0 1 t</td></tr><tr><td>uy</td><td>уй</td><td>уйл / иyl1</td></tr><tr><td>ey</td><td>эй</td><td>ирээрэй / il r e:0 r ey</td></tr><tr><td>^y</td><td>үй</td><td>гүй / g ^y0</td></tr><tr><td>a:</td><td>aa</td><td>аадар / a:1 d a0 r</td></tr><tr><td>e:</td><td>ээ</td><td>ээдэм / e:1 d e0 m</td></tr><tr><td>i:</td><td>ий</td><td>хий / x i:0</td></tr><tr><td>0:</td><td>00</td><td>oocop / o:1 s o0 r</td></tr><tr><td>u:</td><td>yy</td><td>уудам / u:1 d a0 m</td></tr><tr><td>@:</td><td>өө</td><td>өөд / @:1 d</td></tr><tr><td>^:</td><td>YY</td><td>үүд/ ^:1 d</td></tr><tr><td>A</td><td>a</td><td>даль / d A1 L</td></tr><tr><td>0</td><td>о</td><td>боль/ b O1 L</td></tr><tr><td>U</td><td>y</td><td>yрь / U1 R</td></tr></table>



# II.Монгол хэлний авиазүй 

Монгол хэлний авиан талаар олон янзын ангиллыг гадаад дотоодын эрдэмтэд гаргасан байдаг [4]. Хамгийн нарийн нь эгшгийн 25, гийгүүлэгчийн 31 янзаар ангилсан [5] байдаг. Монгол хэлний ярианы үүсгүүрийн судалдгаанд [1], 33 гийгүүлэгч, 20 эгшгийг тодорхойлон ашиглажээ. 

Энэхүү судалгаанд өмнөх авиан загварыг тагнайшсан гийгүүлэгчтэй ойр байрлах тагнайшсан эгшгийг нэмэн сайжруулж тодорхойлов. Нэмэн тодорхойлсон эгшгүүдийн дуудлагын тэмдэглэгээ нь А, О болон U болно. Жишээлбэл “харь" гэдэг үгийн дуудлага нь “ $\mathbf { \dot { x } }$ -A1-R” болно. Хуучин хувилбараар бол энэ үгийг $\mathbf { \dot { X } }$ -a1-R” гэж буулгаж байсан нь энэ үгийн 2 дахь эгшиг авиаг "хар” гэдэг үгийн "х-а1-r" хоёр дахь а авиатай адил тэмдэглэж байсан. Дараах хүснэгтэд зарим үгсийн дуудлагын тэмдэглэгээний жишээг үзүүлэв. 


TABLE II. ЗарИМ ҮГСИЙН БДХ ЖИШЭЭ 




<table><tr><td rowspan=1 colspan=1>Бичлэг</td><td rowspan=1 colspan=1>Дуудлага v1</td><td rowspan=1 colspan=1>Дуудлага v2</td></tr><tr><td rowspan=1 colspan=1>Аргаль</td><td rowspan=1 colspan=1>a1-r|G-a0-L|</td><td rowspan=1 colspan=1>a1-r|G-A0-L|</td></tr><tr><td rowspan=1 colspan=1>Архи</td><td rowspan=1 colspan=1>a1-rX-i0|</td><td rowspan=1 colspan=1>A1-rX-i0|</td></tr><tr><td rowspan=1 colspan=1>Говиор</td><td rowspan=1 colspan=1>G-o1[V-i0-00-r]</td><td rowspan=1 colspan=1>G-O1|V-i0-00-r]</td></tr><tr><td rowspan=1 colspan=1>Суурийн</td><td rowspan=1 colspan=1>s-U:1|R-i:0-ng|</td><td rowspan=1 colspan=1>s-U:1|R-i:0-ng|</td></tr><tr><td rowspan=1 colspan=1>Ярьдаг</td><td rowspan=1 colspan=1>j-a1-R|d-a0-g|</td><td rowspan=1 colspan=1>j-A1-R|d-a0-g|</td></tr><tr><td rowspan=1 colspan=1>Яриулсан</td><td rowspan=1 colspan=1>j-a1|R-i0-u0-1|s-a0-ng|</td><td rowspan=1 colspan=1>j-A1|R-i0-u0-1|s-a0-ng</td></tr></table>



Энэхүү хувилбар нь Монгол хэлний авиан загварын эцсийн хувилбар биш бөгөөд үүнийг зөвхөн Халх аялгууны яриа таних болон яриа үүсгэх хэрэглээний хүрээнд туршиж байгааг дурдах нь зүйтэй. Дээр дурдсанчлан авиан олон янзын ангилал байгаа бөгөөд тэдгээрийг нарийн судалж илүү ерөнхий зориулалтын БДХ загварыг гаргах нь зүйтэй. Мөн ижил бичлэгтэй ч дуудлага өөр үгс (омограф) кирилл Монгол бичвэрийн хувьд бас тОхиолдоно. 

# III. Корпус 

Энэ бүлэгт туршилтад хэрэглэсэн хэлний нөөцүүдийг танилцуулна. Эдгээр нь яриа танилтын туршилтад хэрэглэсэн ярианы корпус болон үгийн сан болно. 

# A. Ярианы корпус 

Аялалын салбарын ВТЕС [11] корпусын Англиас Монгол руу орчуулсан бичвэрийн 2° мянга гаруй өгүүлбэрийг 20 уншигчаар шуугиангүй бүхээгт уншуулан 44КГц давтамжтай ярианы корпус бичиж авав. 

# 1) Яриа танилтын корпус 

Дээрх том корпусаас эрэгтэй 6, эмэгтэй 6 нийт 12 яригчийн 16 мянга орчим үгэлбэрийг яриа танилтын туршилтад хэрэглэхээр таслан бэлдсэн. Дараах хүснэгтэд яригч бүрийн хүйс, уншсан үгэлбэрийн тоо, болон бичлэгийн уртыг харуулав. 

Ярианы бичлэгийг 44КГц-ээс 16КГц моно болгон багасган түүвэрлэж wav форматаар бэлдсэн. 



<table><tr><td rowspan=1 colspan=1>Яригч</td><td rowspan=1 colspan=1>Хүйс</td><td rowspan=1 colspan=1>Урт, цаг</td><td rowspan=1 colspan=1>#Үгэлбэр</td></tr><tr><td rowspan=1 colspan=1>1</td><td rowspan=1 colspan=1>m</td><td rowspan=1 colspan=1>8.39</td><td rowspan=1 colspan=1>2,711</td></tr><tr><td rowspan=1 colspan=1>2</td><td rowspan=1 colspan=1>f</td><td rowspan=1 colspan=1>6.55</td><td rowspan=1 colspan=1>2,849</td></tr><tr><td rowspan=1 colspan=1>3</td><td rowspan=1 colspan=1>m</td><td rowspan=1 colspan=1>0.61</td><td rowspan=1 colspan=1>1,006</td></tr><tr><td rowspan=1 colspan=1>4</td><td rowspan=1 colspan=1>m</td><td rowspan=1 colspan=1>1.14</td><td rowspan=1 colspan=1>708</td></tr><tr><td rowspan=1 colspan=1>5</td><td rowspan=1 colspan=1>f</td><td rowspan=1 colspan=1>2.63</td><td rowspan=1 colspan=1>1,007</td></tr><tr><td rowspan=1 colspan=1>6</td><td rowspan=1 colspan=1>f</td><td rowspan=1 colspan=1>0.96</td><td rowspan=1 colspan=1>1,000</td></tr><tr><td rowspan=1 colspan=1>7</td><td rowspan=1 colspan=1>m</td><td rowspan=1 colspan=1>0.52</td><td rowspan=1 colspan=1>471</td></tr><tr><td rowspan=1 colspan=1>8</td><td rowspan=1 colspan=1>f</td><td rowspan=1 colspan=1>1.12</td><td rowspan=1 colspan=1>982</td></tr><tr><td rowspan=1 colspan=1>9</td><td rowspan=1 colspan=1>m</td><td rowspan=1 colspan=1>2.40</td><td rowspan=1 colspan=1>1,996</td></tr><tr><td rowspan=1 colspan=1>10</td><td rowspan=1 colspan=1>f</td><td rowspan=1 colspan=1>1.70</td><td rowspan=1 colspan=1>1,000</td></tr><tr><td rowspan=1 colspan=1>11</td><td rowspan=1 colspan=1>m</td><td rowspan=1 colspan=1>1.55</td><td rowspan=1 colspan=1>1,230</td></tr><tr><td rowspan=1 colspan=1>12</td><td rowspan=1 colspan=1>f</td><td rowspan=1 colspan=1>6.08</td><td rowspan=1 colspan=1>1,500</td></tr><tr><td rowspan=1 colspan=1>Нийт</td><td rowspan=1 colspan=1>6+6=12</td><td rowspan=1 colspan=1>33.65</td><td rowspan=1 colspan=1>16,460</td></tr></table>



Нийт 33 цагийн 16 битийн түүвэрлэлттэй алдагдал шахалтгүй wave форматтай цэвэр бичлэг болов. Бичлэгийн дохио шуугианы харьцаа (signal-to-noise ratio, SNR) ойролцоогоор 30-40 dB. 

# В. Үгийн сан 

Ярианы санг үүсгэсэн бичвэрээс ялгаатай үгсийг гаргаж тэдгээрийн дуудлагыг [1]-д ашигласан БДХ эхний хувилбараар гаргаж үгийн санг үүсгэв. Нийт 16 мянган үглэбэрт 14 мянган ялгаатай үг байв. Энэхүү үгсээс 1,000 орчим үгсийн дуудлагыг шинэчлэн гараар нэмж үгийн сангийн шинэ 2 дугаар хувилбарыг гаргасан. Дараагийн туршилтуудад эдгээр 2 хувилбарыг харьцуулж үнэлсэн болно. 

# IV. ТуршИлТ 

Кирилл Монгол бичгийн БДХ хувилбарыг яриа танилт, яриа үүсгүүр болон чиглүүлэгт сургалт гэсэн гурван өөр горимоор туршиж үнэлэв. 

# A. Яриа танилт 

Энэхүү туршилтад Калди яриа танилтын хэрэгслийг [8] ашиглан өөрсдийн ярианы сан дээр туршив. Калди яриа танилтын хэрэгсэл нь СMU sрhinх, Julius гэх мэт бусад хэрэгслүүдтэй харьцуулахад сүүлийн үед яриа боловсруулалтын судалгааны хүрээнд маш их ашиглагдаж буй, нээлттэй эхийн, маш олон төрлийн туршилтын цэстэй HOM. Зөвхөн судалгаанызорилгоор төдийгүй бодит хэрэглэний горимд ажиллах чадвартай Си хэл дээр бичигдсэн, төгсгөлөг төлөвт хэрэгсэл дээр суурилсан хурдан ажиллагаатай хэрэгсэл юм. 

Эхний энгийн харьцуулалт хийх үүднээс энгийн GMМ загварыг Калдигийн гт цэс дээр сургасан. Хэлний загварыг SRI хэлний загварын хэрэгслээр (SRILМ) зөвхөн сургалтын болон тест ярианы бичвэрээс гуравлсан дүрэмт загварыг үүсгэв. 

Тест санг нийт ярианы сангийн уртын 10 хувь орчимтой дүйх 3 болон 5 дугаар яригчийг тусад нь авч сонгов. Улдсэн 10 яригчийг сургалтын сангаар авав. 

Дараах хүснэгтэд Калди сургалтын акустик загвар бүрээр харьцуулж буй БдХ-ийн үгийн алдааны хувь (Word error rate, WER ) (багана 2 бa 3) болон сүүлийн хувилбарын эхний хувилбартай харьцуулсан харьцангуй сайжралтыг (багана 3/ Харь.Сайжр.) харуулав. 


TABLE IV. МОНГОЛ ХЭЛНИЙ ЯРИА ТАНИЛТЫН РМ ЦЭСИЙН УР ДҮН 




<table><tr><td rowspan=1 colspan=1>Калди акустикзагвар</td><td rowspan=1 colspan=1>WER,үгийн санv2</td><td rowspan=1 colspan=1>WER,үгийн санv1</td><td rowspan=1 colspan=1>Харь.Сайжр.</td></tr><tr><td rowspan=1 colspan=1>combined</td><td rowspan=1 colspan=1>2.84</td><td rowspan=1 colspan=1>3.03</td><td rowspan=1 colspan=1>6.69%</td></tr><tr><td rowspan=1 colspan=1>sgmm2_4a</td><td rowspan=1 colspan=1>2.43</td><td rowspan=1 colspan=1>2.76</td><td rowspan=1 colspan=1>13.58%</td></tr><tr><td rowspan=1 colspan=1>tri3b</td><td rowspan=1 colspan=1>2.59</td><td rowspan=1 colspan=1>2.68</td><td rowspan=1 colspan=1>3.47%</td></tr><tr><td rowspan=1 colspan=1>tri2b</td><td rowspan=1 colspan=1>3.53</td><td rowspan=1 colspan=1>3.60</td><td rowspan=1 colspan=1>1.98%</td></tr><tr><td rowspan=1 colspan=1>tri2a</td><td rowspan=1 colspan=1>3.80</td><td rowspan=1 colspan=1>4.02</td><td rowspan=1 colspan=1>5.79%</td></tr><tr><td rowspan=1 colspan=1>tril</td><td rowspan=1 colspan=1>3.78</td><td rowspan=1 colspan=1>4.04</td><td rowspan=1 colspan=1>6.88%</td></tr><tr><td rowspan=1 colspan=1>mono</td><td rowspan=1 colspan=1>7.89</td><td rowspan=1 colspan=1>10.74</td><td rowspan=1 colspan=1>36.12%</td></tr><tr><td rowspan=1 colspan=1>Дундаж</td><td rowspan=1 colspan=1>3.84</td><td rowspan=1 colspan=1>4.41</td><td rowspan=1 colspan=1>10.65%</td></tr></table>



БДХ сүүлийн загвараар үүсгэсэн үгийн сан хувилбар 2 нь энэ туршилтын ярианы сан дээр яриа танилтын үр дүнг дунджаар 10.65 хувиар өсгөж байна. 

# B.Яриа үүсгүүр 

НММ суурилсан яриа үүсгэх хоолойг НТS [9] хэрэгслээр үүсгэж сонсголын тестээр үнэлэв. Хоолойг үүсгэхдээ бичвэрийг ярианд хөрвүүлэхэд [1] зориулсан 3,000 өгүүлбэр бүхий үүсгэсэн санг ашигласан. 

Бичвэрийг ярианд хөрвүүлэх хоолойг сургасны дараа санамсаргүй 20 үг сонгон БДХ хувилбар бүрээр үүсгэж 55 хүнээс (18-аас 48 насны 33 эр, $2 2 \ \mathrm { \ s u }$ вэб интерфейсээр сонсгож үнэлүүлэв. Сонсогчид үүсгэсэн үгсийг сонсож хамгийн сайн гэсэн хувилбарыг нь сонгосон. Нийт 1,100 сонголт байв (хүн бүрийн 20). 


TABLE V. ЯРИА ҮҮСГҮҮРИЙН ҮНЭЛГЭЭ 




<table><tr><td rowspan=1 colspan=1>Too</td><td rowspan=1 colspan=1>БДХ v1</td><td rowspan=1 colspan=1>БДХ v2</td></tr><tr><td rowspan=1 colspan=1>Санал</td><td rowspan=1 colspan=1>470</td><td rowspan=1 colspan=1>630</td></tr><tr><td rowspan=1 colspan=1>Хувь</td><td rowspan=1 colspan=1>21.37</td><td rowspan=1 colspan=1>78.63</td></tr></table>



Үнэлгээ өгсөн сонсогчдын ихэнх нь БДХ хувилбар 2-ыг илүүд үзсэн байна. Энэхүү хувилбараар синтетикээр үүсгэсэн ярианд зарим нэгэн муу үүсэн үгс байсан. Энэ нь сургалтын корпуст хангальттай хэмжээний түүвэр байгаагүйтэй нэг талаараа холбоотой гэж үзэж байна. Гэсэн хэдий ч нийт дунджаар хувилбар $2 \ \mathrm { \textrm { H b } }$ хувилбар 1 ээсээ илүү үнэлгээтэй байв. 

Энэхүү Sеqиіtur [10] хэрэгсэл нь холбоост-дарааллын загварт суурилсан, өгөгдөлдсуурилсан бичвэрийг дуудлагад хөрвүүлэгч нээлттэй эхийн хэрэгсэл юм. 

![](images/55f251b66f6abf53e3264cbf132a65588b342ce44a3e2424425bfbbba4097043.jpg)



Fig. 1. Sequitur output example with errors 


Сургалтын өгөгдөл дээр загварыг 6 алхам сургасны дараа тэмдэгтийн алдаа $5 . 4 1 \%$ рарав. 

Хамгийн их алдаж буй тохиолдол нь дээрх зурагт үзүүлсэнчлэн тагнайшсан гийгүүлэгчийн дараа орсон урт эгшгийн тохиолдол байна. Энэ нь уламжлалт хэл шинжээчдийн дунд ч гэсэн өөр өөрөөр тодорхойлогдсон байдаг [5]. 


TABLE VI. SEQUITUR TУPШИЛTЫH YP ДYH 




<table><tr><td rowspan=1 colspan=1>Алхам</td><td rowspan=1 colspan=1>Тэмдэгтийналдаа, %</td><td rowspan=1 colspan=1>Үгийн алдаа, %</td></tr><tr><td rowspan=1 colspan=1>3</td><td rowspan=1 colspan=1>5.51</td><td rowspan=1 colspan=1>22.93</td></tr><tr><td rowspan=1 colspan=1>4</td><td rowspan=1 colspan=1>5.39</td><td rowspan=1 colspan=1>23.03</td></tr><tr><td rowspan=1 colspan=1>5</td><td rowspan=1 colspan=1>5.40</td><td rowspan=1 colspan=1>23.43</td></tr><tr><td rowspan=1 colspan=1>6</td><td rowspan=1 colspan=1>5.41</td><td rowspan=1 colspan=1>23.52</td></tr></table>



Эдгээр асуудлуудыг цаашид дэлгэрүүлэн судалж шийдвэрлүүштэй. 

# V. Дүгнэлт 

Кирилл Монгол бичвэрийг дуудлагад хөрвүүлэх модулийг анх амжилттай хөгжүүлж яриа үүсгүүрийн хүрээнд хэрэгжүүлж туршсан [1]. Энэ өгүүлэлд түүний шинэчилсэн загварыг танилцуулж яриа танилт, яриа үүсгүүр болон чиглүүлэгтэй сургалтаар үнэлгээ өглөө. Туршилтын үр дүн бүгд БдХ шинэ хувилбарын давуу байдлыг илэрхийлсэн. 

Тагнайшсан гийгүүлэгчийн дараа орох урт эгшгийн загвар гэх мэт нэмэлт сайжруулалтыг хийж бүр ерөнхий зориулалтын БДХ загварыг сайжруулах шаардлагатай. 

БДХ загварын зэрэгцээ Монгол хэлний яриа танилтын шинэ корпусыг танилцуулж туршилтад ашиглалаа. Энэн нь МуйС дээр хөгжүүлж байгаа томоохон хэмжээний корпусын нэг хэсэг нь болно. Цаашлаад яриа танилтын туршилт энэ том корпус дээр хийгдэнэ. 

# C. Чиглүүлэгтэй сургалт 

Энэ хэсэгт БДХ хувилбар 2-ыг чиглүүлэгтэй сургалтаар үнэллээ. Энэхүү хувилбараар үүсгэсэн 14 мянган үгтэй дуудлагын толийг Sеqиitur [10] хэрэгслээр сургаж гараар үүсгэсэн 1 мянган үгтэй сангийн дуудлагатай харьцуулж шалгав. 

# ТАЛАРХАЛ 

Яриа танилтын корпусыг бэлдэхэд яриа бичүүлэх, үглэбэрээр таслах, гараар зэрэгцүүлэлтийг хянах зэрэг нүсэр ажилд гүн туслалцаа үзүүлсэн бүх хүнд талархал илэрхийлье. 

# REFERENCES 

[1] Chagnaa Altangerel, Jaimai Purev, Chatchawarn Hansakunbuntheung: An Evaluation of Mongolian Data-Driven Text-to-Speech, Oriental COCOSDA 2013.   
[2] Chatchawarn Hansakunbuntheung, Ausdang Thangthai, Nattanun Thatphithakkul and Altangerel Chagnaa: MONGOLIAN SPEECH CORPUS FOR TEXT-TO-PEECH DEVELOPMENT, proc. Oriental COCOSDA 2011, pp , Hsinchu, Taiwan,26-28 Oct, 2011.   
[3] A.Altangerel, and, B.Damdinsuren, "Research Report on ASR Development for Mongolian”, PAN localization Project Phase II , 2009.   
[4] Jan-Olaf Svantesson, Anna Tsendina, Anastasia Karlsson and Vivan Franzen,The Phonology of Mongolian, Oxfor Linguistics, 2005.   
[5] Bulgantamir, S. Acoustic Analysis on the Palatalized Vowels of Modern Mongolian. Advances in Language and Literary Studies, 6(6), 107-110, (2015).   
[6] Möömöö, S. Mongol xelnij avia züi, Ulaanbaatar, Mongolia: National Press, (1979).   
[7] Zhang H., Bao F., Gao G. (2015) Mongolian Speech Recognition Based on Deep Neural Networks. In: Sun M., Liu Z., Zhang M., Liu Y. (eds) Chinese Computational Linguistics and Natural Language Processing Based on Naturall Annotated Big Data. Lecture Notes in Computer Science, vol 9427. Springer, Cham.   
[8] Povey, D., Ghoshal, A., Boulianne, G., Burget, L., Glembek, O., Goel, N., & Silovsky, J.: The Kaldi speech recognition toolkit. Workshop on automatic speech recognition and understanding (No. EPFL-CONF192584). IEEE Signal Processing Society (2011).   
[9] K. Tokuda, T. Yoshimura, T. Masuko, T. Kobayashi, T. Kitamura, Speech parameter generation algorithms for HMM-based speech synthesis, Proc. of ICASSP, pp.1315-1318, June 2000.   
[10] M. Bisani and H. Ney: "Joint-Sequence Models for Grapheme-toPhoneme Conversion". Speech Communication, Volume 50, Issue 5, May 2008, Pages 434-451.   
[11] Takezawa, T., Sumita, E., Sugaya, F., Yamamoto, H., Yamamoto, S.: Toward a broad-coverage bilingual corpus for speech translation of travel conversation in the real world. In: Proceedings of the third International Conference on Language Resources and Evaluation (LREC) 2002.   
[12] Nakagawa, Seiichi, et al. "Development of large vocabulary continuous speech recognition system for Mongolian language." Spoken Language Technologies for Under-Resourced Languages. 2012.   
[13] Hansakunbuntheung, Chatchawarn, and Sumonmas Thatphithakkul. "Unsupervised graphoneme alignment evaluation for grapheme-tophoneme conversion on complex asian-language orthographies." Coordination and Standardization of Speech Databases and Assessment Techniques (O-COCOSDA), 2016 Conference of The Oriental Chapter of International Committee for. IEEE, 2016.
